==> cdk-lambda-bash-0.3.2.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.3.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.3.1...v0.3.2) (2021-03-16)

### [0.3.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.3.0...v0.3.1) (2021-03-16)

### [0.2.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.1...v0.2.2) (2021-03-16)


### Bug Fixes

* update snap ([#12](https://github.com/pahud/cdk-lambda-bash/issues/12)) ([8b8b3e5](https://github.com/pahud/cdk-lambda-bash/commit/8b8b3e5fb4a23795f1f4f9c18a61d672521d86a8))

## [0.3.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.1...v0.3.0) (2021-03-16)


### Features

* support lambda environment variables ([c6cee03](https://github.com/pahud/cdk-lambda-bash/commit/c6cee03382d1c9e6fed9cf44e6e5927d5ce53a02))
* support Lambda environment variables ([#11](https://github.com/pahud/cdk-lambda-bash/issues/11)) ([59a3498](https://github.com/pahud/cdk-lambda-bash/commit/59a349874a7bdd3b46da7ada43346a3c23ff88a0))


### Bug Fixes

* update snap ([696d912](https://github.com/pahud/cdk-lambda-bash/commit/696d912a8a8ca96a67f1e7eeaf9e182274a9c1a9))

### [0.2.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.0...v0.2.1) (2021-03-15)

## [0.2.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.2...v0.2.0) (2021-03-15)


### Features

* **core:** custom dockerfile ([#8](https://github.com/pahud/cdk-lambda-bash/issues/8)) ([2aad198](https://github.com/pahud/cdk-lambda-bash/commit/2aad1989cf29305af1e52a6ffc0821d69ea55921)), closes [#7](https://github.com/pahud/cdk-lambda-bash/issues/7)

### [0.1.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.1...v0.1.2) (2021-03-15)

### [0.1.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.0...v0.1.1) (2021-03-15)

## [0.1.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.4...v0.1.0) (2021-03-15)

### [0.0.4](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.3...v0.0.4) (2021-03-15)

### [0.0.3](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.2...v0.0.3) (2021-03-15)

### [0.0.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.1...v0.0.2) (2021-03-15)

### 0.0.1 (2021-03-15)

==> cdk-lambda-bash-0.4.1.tar.gz: package/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file. See [standard-version](https://github.com/conventional-changelog/standard-version) for commit guidelines.

### [0.4.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.4.0...v0.4.1) (2021-03-25)


### Features

* support conditional user function execution ([#32](https://github.com/pahud/cdk-lambda-bash/issues/32)) ([decaed8](https://github.com/pahud/cdk-lambda-bash/commit/decaed872174651e7f5b4ec8d24bf9ce259e0de1)), closes [#30](https://github.com/pahud/cdk-lambda-bash/issues/30)

## [0.4.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.3.2...v0.4.0) (2021-03-24)


### Features

* support runOnUpdate property ([629a967](https://github.com/pahud/cdk-lambda-bash/commit/629a967bec0dd09d20965671352bb496172fc137))
* support runOnUpdate property ([#28](https://github.com/pahud/cdk-lambda-bash/issues/28)) ([381de0b](https://github.com/pahud/cdk-lambda-bash/commit/381de0bfa4e63f6a75a7448af8fc194aa8d210ed))
* support runOnUpdate property ([#29](https://github.com/pahud/cdk-lambda-bash/issues/29)) ([5f338b3](https://github.com/pahud/cdk-lambda-bash/commit/5f338b37fbaf94efe56b980c3ccd32d05422c617))

### [0.3.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.3.1...v0.3.2) (2021-03-16)

### [0.3.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.3.0...v0.3.1) (2021-03-16)

### [0.2.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.1...v0.2.2) (2021-03-16)


### Bug Fixes

* update snap ([#12](https://github.com/pahud/cdk-lambda-bash/issues/12)) ([8b8b3e5](https://github.com/pahud/cdk-lambda-bash/commit/8b8b3e5fb4a23795f1f4f9c18a61d672521d86a8))

## [0.3.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.1...v0.3.0) (2021-03-16)


### Features

* support lambda environment variables ([c6cee03](https://github.com/pahud/cdk-lambda-bash/commit/c6cee03382d1c9e6fed9cf44e6e5927d5ce53a02))
* support Lambda environment variables ([#11](https://github.com/pahud/cdk-lambda-bash/issues/11)) ([59a3498](https://github.com/pahud/cdk-lambda-bash/commit/59a349874a7bdd3b46da7ada43346a3c23ff88a0))


### Bug Fixes

* update snap ([696d912](https://github.com/pahud/cdk-lambda-bash/commit/696d912a8a8ca96a67f1e7eeaf9e182274a9c1a9))

### [0.2.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.2.0...v0.2.1) (2021-03-15)

## [0.2.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.2...v0.2.0) (2021-03-15)


### Features

* **core:** custom dockerfile ([#8](https://github.com/pahud/cdk-lambda-bash/issues/8)) ([2aad198](https://github.com/pahud/cdk-lambda-bash/commit/2aad1989cf29305af1e52a6ffc0821d69ea55921)), closes [#7](https://github.com/pahud/cdk-lambda-bash/issues/7)

### [0.1.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.1...v0.1.2) (2021-03-15)

### [0.1.1](https://github.com/pahud/cdk-lambda-bash/compare/v0.1.0...v0.1.1) (2021-03-15)

## [0.1.0](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.4...v0.1.0) (2021-03-15)

### [0.0.4](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.3...v0.0.4) (2021-03-15)

### [0.0.3](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.2...v0.0.3) (2021-03-15)

### [0.0.2](https://github.com/pahud/cdk-lambda-bash/compare/v0.0.1...v0.0.2) (2021-03-15)

### 0.0.1 (2021-03-15)
